searchData={"items":[{"type":"module","title":"Logbook","doc":"A category (or tags) based logger for Elixir.\n\nLogbook is a wrapper aroud Elixir Logger that enables a to specify one or more tags\nfor each invocation in order to be able to set different log levels for each tag.\n\nTagging logs is useful to track log informations around different modules and\nenable only one (or more) specific tags at different log levels than the default\nLogger instead of having (for example) all debug logs enabled.\n\nIn the following example when calling `delete_all` and having the `:audit` tag level\nset to at least `:info`, both \"Deleting user...\" and \"Deleting domain\" logs will be produced.\nIf only `:domain` or `:user` tags have log level set to `:info` only the corresponding logs\nwill be produced.","ref":"Logbook.html"},{"type":"module","title":"Example - Logbook","doc":"require Logbook\n\n    def delete_user(user) do\n      Logbook.info([:audit, :user], \"Deleting user #{inspect(user)}\")\n      # ...\n    end\n\n    def delete_domain(domain) do\n      Logbook.info([:audit, :domain], \"Deleting domain #{inspect(domain)}\")\n      # ...\n    end\n\n    def delete_all(user, domain) do\n      delete_domain(domain)\n      delete_user(user)\n    end\n\nLog levels for each tag can be set using `Logbook.set_level/2`:\n\n      # For a single tag\n      Logbook.set_level(:audit, :info)\n\n      # or for many tags at once\n      Logbook.set_level([:audit, :user, :domain], :info)\n\nIs possible to set the default level for all tags, by setting the `:default_tag_level`\nconfig option for `:logbook` app (defaults to `:warning`):\n\n      import Config\n\n      config :logbook, :default_tag_level, :warning\n\nThe `:default_tag_level` option is used when Logbook sees tags for the first time\nduring runtime and set them internally with the above level.\n\nAs a bonus, Logbook also creates a module-level tag automatically, in order to\nbe able to enable log statements at once in a single module:\n\n    defmodule Foo\n      require Logbook\n\n      def delete_user(user) do\n        Logbook.info([:audit, :user], \"Deleting user #{inspect(user)}\")\n        # ...\n      end\n\n      def delete_domain(domain) do\n        Logbook.info([:audit, :domain], \"Deleting domain #{inspect(domain)}\")\n        # ...\n      end\n    end\n\nWith the above example is possible to `Logbook.set_level(Foo, :info)` to enable\nall Logbook calls inside the module `Foo`.\n\nAs with `:default_tag_level` is possible to set also default module-level logging\nwith:\n\n      import Config\n\n      config :logbook, :default_module_level, :warning\n\nBy default `:default_module_level` is set to `:none` (no module-level logging).\n\n`Logbook` supports all `Logger` levels, along with the additional `:none` level\nthat disables it for the specified tag/module.\n\nBeing a wrapper for `Logger`, if the `Logger` log level is less that `Logbook`\nlog level, the logs will not be produced, because are filtered by `Logger` log levels.\nExample:\n\n      Logger.configure(level: :warning)\n      Logbook.set_level(:foo, :debug)\n\n      Logbook.debug(:foo, \"This will not be emitted\")","ref":"Logbook.html#module-example"},{"type":"macro","title":"Logbook.alert/3","doc":"","ref":"Logbook.html#alert/3"},{"type":"macro","title":"Logbook.critical/3","doc":"","ref":"Logbook.html#critical/3"},{"type":"macro","title":"Logbook.debug/3","doc":"","ref":"Logbook.html#debug/3"},{"type":"macro","title":"Logbook.emergency/3","doc":"","ref":"Logbook.html#emergency/3"},{"type":"function","title":"Logbook.enabled?/2","doc":"Checks wheter the tag has the specified log level equal o higher than the configured one.\n\n    iex> Logbook.set_level(:foo, :info)\n    :ok\n    iex> Logbook.enabled?(:foo, :debug)\n    false\n    iex> Logbook.enabled?(:foo, :warning)\n    true\n\nIf a list of tags is passed, returns `true` if any of the tag log level is equal or lower than\nthe passed one.","ref":"Logbook.html#enabled?/2"},{"type":"macro","title":"Logbook.error/3","doc":"","ref":"Logbook.html#error/3"},{"type":"macro","title":"Logbook.info/3","doc":"","ref":"Logbook.html#info/3"},{"type":"type","title":"Logbook.level/0","doc":"","ref":"Logbook.html#t:level/0"},{"type":"function","title":"Logbook.module_enabled?/2","doc":"Like `enabled?/2` checks if the given module has a configured log level equal\nor lower than the given level.","ref":"Logbook.html#module_enabled?/2"},{"type":"macro","title":"Logbook.notice/3","doc":"","ref":"Logbook.html#notice/3"},{"type":"function","title":"Logbook.reset/0","doc":"","ref":"Logbook.html#reset/0"},{"type":"function","title":"Logbook.set_level/2","doc":"Sets log level for the specific tag or list of tags.","ref":"Logbook.html#set_level/2"},{"type":"type","title":"Logbook.tag_or_tags/0","doc":"","ref":"Logbook.html#t:tag_or_tags/0"},{"type":"function","title":"Logbook.tags/0","doc":"Returns a map containing the tags/modules seen at runtime with the corresponding\nconfigured log level. This list is built at runtime, so if a `Logbook` loggin fun\nhas never be called, the corresponding tag will not be shown here.","ref":"Logbook.html#tags/0"},{"type":"macro","title":"Logbook.warning/3","doc":"","ref":"Logbook.html#warning/3"},{"type":"module","title":"Logbook.Backends.Logfmt","doc":"Log format file based backend.\n\nThis backend is opinionated for optimal support of Logbook tagged logging,\nso a tags entry is always added even if no tags (ie called by plain Logger)\nare given.\n\nThis backend cannot be configured, all metadata is always logged, along\nwith additional fields.\n\nHere is an example of how to configure the `Logfmt` backend in a `config/config.exs` file:\n\n    # Configures Elixir's Logger\n    config :logger,\n      backends: [\n        :console,\n        {Logbook.Backends.Logfmt, :log_fmt_log}\n      ]\n\n    # Log formar file log\n    config :logger, :log_fmt_log, path: \"/var/log/somefile.log\"","ref":"Logbook.Backends.Logfmt.html"},{"type":"module","title":"Logbook.Formatters.Logfmt","doc":"A logfmt formatter backend for the Elixir console logger backend, tailored\nto Logbook needs.\n\nIdeally it should be used with the `metadata: :all` option of the console\nbackend.\n\nThe log line is made of the following keys:\n- `date`: date of the entry, in YYYY-MM-DD format.\n- `time`: time of the event, in hh:mm:ss.msec.\n- `level`: the log level.\n- `msg`: the actual log message.\n- `tag`: Logbook specific: comma separated list of logbook tags, fallbacks to\n         `default` if the log entry has no tags.\n- `module`: module emitting the log.\n- `function`: function emitting the log, in the form function/arity.\n- `vm_pid`: OS pid of the erlang vm.\n- `host`: hostname of the system, as returned from `:inet.gethostname/0`.\n\nRemainig metadata is appended to this list. Note that the `:mfa` key is dropped\nsince `module` and `function` are already reported.","ref":"Logbook.Formatters.Logfmt.html"},{"type":"function","title":"Logbook.Formatters.Logfmt.format/4","doc":"","ref":"Logbook.Formatters.Logfmt.html#format/4"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}